@@ -24,8 +24,6 @@ from sklearn.metrics import silhouette_samples
 from sklearn.calibration import calibration_curve
 from sklearn.utils import deprecated
 
-from scipy import interpolate
-
 from scikitplot.helpers import binary_ks_curve, validate_labels
 from scikitplot.helpers import cumulative_gain_curve
 
@@ -152,7 +150,7 @@ def plot_confusion_matrix(y_true, y_pred, labels=None, true_labels=None,
     else:
         ax.set_title('Confusion Matrix', fontsize=title_fontsize)
 
-    image = ax.imshow(cm, interpolation='nearest', cmap=plt.cm.get_cmap(cmap))
+    image = ax.imshow(cm, interpolation='nearest', cmap=plt.get_cmap(cmap))
     plt.colorbar(mappable=image)
     x_tick_marks = np.arange(len(pred_classes))
     y_tick_marks = np.arange(len(true_classes))
@@ -281,7 +279,7 @@ def plot_roc_curve(y_true, y_probas, title='ROC Curves',
     # Then interpolate all ROC curves at this points
     mean_tpr = np.zeros_like(all_fpr)
     for i in range(len(classes)):
-        mean_tpr += interpolate(all_fpr, fpr[i], tpr[i])
+        mean_tpr += np.interp(all_fpr, fpr[i], tpr[i])
 
     # Finally average it and compute AUC
     mean_tpr /= len(classes)
@@ -302,7 +300,7 @@ def plot_roc_curve(y_true, y_probas, title='ROC Curves',
 
     if 'each_class' in curves:
         for i in range(len(classes)):
-            color = plt.cm.get_cmap(cmap)(float(i) / len(classes))
+            color = plt.get_cmap(cmap)(float(i) / len(classes))
             ax.plot(fpr[i], tpr[i], lw=2, color=color,
                     label='ROC curve of class {0} (area = {1:0.2f})'
                     ''.format(classes[i], roc_auc[i]))
@@ -415,7 +413,7 @@ def plot_roc(y_true, y_probas, title='ROC Curves',
                                                 pos_label=classes[i])
         if to_plot:
             roc_auc = auc(fpr_dict[i], tpr_dict[i])
-            color = plt.cm.get_cmap(cmap)(float(i) / len(classes))
+            color = plt.get_cmap(cmap)(float(i) / len(classes))
             ax.plot(fpr_dict[i], tpr_dict[i], lw=2, color=color,
                     label='ROC curve of class {0} (area = {1:0.2f})'
                           ''.format(classes[i], roc_auc))
@@ -440,7 +438,7 @@ def plot_roc(y_true, y_probas, title='ROC Curves',
         # Then interpolate all ROC curves at this points
         mean_tpr = np.zeros_like(all_fpr)
         for i in range(len(classes)):
-            mean_tpr += interpolate(all_fpr, fpr_dict[i], tpr_dict[i])
+            mean_tpr += np.interp(all_fpr, fpr_dict[i], tpr_dict[i])
 
         # Finally average it and compute AUC
         mean_tpr /= len(classes)
@@ -651,7 +649,7 @@ def plot_precision_recall_curve(y_true, y_probas,
 
     if 'each_class' in curves:
         for i in range(len(classes)):
-            color = plt.cm.get_cmap(cmap)(float(i) / len(classes))
+            color = plt.get_cmap(cmap)(float(i) / len(classes))
             ax.plot(recall[i], precision[i], lw=2,
                     label='Precision-recall curve of class {0} '
                           '(area = {1:0.3f})'.format(classes[i],
@@ -763,7 +761,7 @@ def plot_precision_recall(y_true, y_probas,
                 probas[:, i])
             precision, recall, _ = precision_recall_curve(
                 y_true, probas[:, i], pos_label=classes[i])
-            color = plt.cm.get_cmap(cmap)(float(i) / len(classes))
+            color = plt.get_cmap(cmap)(float(i) / len(classes))
             ax.plot(recall, precision, lw=2,
                     label='Precision-recall curve of class {0} '
                           '(area = {1:0.3f})'.format(classes[i],
@@ -885,7 +883,7 @@ def plot_silhouette(X, cluster_labels, title='Silhouette Analysis',
         size_cluster_i = ith_cluster_silhouette_values.shape[0]
         y_upper = y_lower + size_cluster_i
 
-        color = plt.cm.get_cmap(cmap)(float(i) / n_clusters)
+        color = plt.get_cmap(cmap)(float(i) / n_clusters)
 
         ax.fill_betweenx(np.arange(y_lower, y_upper),
                          0, ith_cluster_silhouette_values,
@@ -1026,7 +1024,7 @@ def plot_calibration_curve(y_true, probas_list, clf_names=None, n_bins=10,
         fraction_of_positives, mean_predicted_value = \
             calibration_curve(y_true, probas, n_bins=n_bins)
 
-        color = plt.cm.get_cmap(cmap)(float(i) / len(probas_list))
+        color = plt.get_cmap(cmap)(float(i) / len(probas_list))
 
         ax.plot(mean_predicted_value, fraction_of_positives, 's-',
                 label=clf_names[i], color=color)
